==> base-domain-RD1000957-20190605.070101-1-sources.jar: com/thebeastshop/scm/po/ProdSku.java <==
package com.thebeastshop.scm.po;

import java.math.BigDecimal;

import pers.richard.ormybatis.domain.po.IdPo;

public class ProdSku extends IdPo {
	private Integer productId;
	private String prodCode;
	private String skuCode;
	private String skuCategoryDesc;
	private Integer minAmount = 1;
	private Integer combined = 0;
	private String attrs;
	private BigDecimal salesPrice;
	private BigDecimal singleSkuSalesPrice;
	private String skuCategoryName;
	private Integer active = 1;

	public ProdSku(){}
	
	public final static String
		F_PRODUCT_ID = "product_id",
		F_SKU_CODE = "sku_code",
		F_MIN_AMOUNT = "min_amount",
		F_COMBINED = "combined",
		F_SALES_PRICE = "sales_price",
		F_ACTIVE = "active";


	public Integer getProductId() {return productId;}
	public void setProductId(Integer productId) {this.productId = productId;}

	public String getProdCode() {
		return prodCode;
	}

	public void setProdCode(String prodCode) {
		this.prodCode = prodCode;
	}

	public String getSkuCode() {return skuCode;}
	public void setSkuCode(String skuCode) {this.skuCode = skuCode;}

	public String getSkuCategoryDesc() {
		return skuCategoryDesc;
	}

	public void setSkuCategoryDesc(String skuCategoryDesc) {
		this.skuCategoryDesc = skuCategoryDesc;
	}

	public Integer getMinAmount() {return minAmount;}
	public void setMinAmount(Integer minAmount) {
		if (minAmount == null) {
			minAmount = 1;
		}
		this.minAmount = minAmount;
	}

	public Integer getCombined() {return combined;}
	public void setCombined(Integer combined) {this.combined = combined;}

	public String getAttrs() {
		return attrs;
	}

	public void setAttrs(String attrs) {
		this.attrs = attrs;
	}

	public BigDecimal getSalesPrice() {return salesPrice;}
	public void setSalesPrice(BigDecimal salesPrice) {this.salesPrice = salesPrice;}

	public BigDecimal getSingleSkuSalesPrice() {
		return singleSkuSalesPrice;
	}

	public void setSingleSkuSalesPrice(BigDecimal singleSkuSalesPrice) {
		this.singleSkuSalesPrice = singleSkuSalesPrice;
	}

	public String getSkuCategoryName() {
		return skuCategoryName;
	}

	public void setSkuCategoryName(String skuCategoryName) {
		this.skuCategoryName = skuCategoryName;
	}

	public Integer getActive() {return active;}
	public void setActive(Integer active) {this.active = active;}
}

==> base-domain-RD1004374-20211202.024329-2-sources.jar: com/thebeastshop/scm/po/ProdSku.java <==
package com.thebeastshop.scm.po;

import java.math.BigDecimal;

import pers.richard.ormybatis.domain.po.IdPo;

public class ProdSku extends IdPo {
	private Integer productId;
	private String prodCode;
	private String skuCode;
	private String skuCategoryDesc;
	private Integer minAmount = 1;
	private Integer combined = 0;
	private String attrs;
	private BigDecimal salesPrice;
	private BigDecimal singleSkuSalesPrice;
	private String skuCategoryName;
	private Integer active = 1;
	private String bu;
	private String attrValue1;
	private String attrValue2;
	private String attrValue3;
	private String spvImg;
	private Integer showCombinedPrice = 1;

	public ProdSku(){}
	
	public final static String
		F_PRODUCT_ID = "product_id",
		F_SKU_CODE = "sku_code",
		F_MIN_AMOUNT = "min_amount",
		F_COMBINED = "combined",
		F_SALES_PRICE = "sales_price",
		F_ACTIVE = "active";


	public Integer getProductId() {return productId;}
	public void setProductId(Integer productId) {this.productId = productId;}

	public String getProdCode() {
		return prodCode;
	}

	public void setProdCode(String prodCode) {
		this.prodCode = prodCode;
	}

	public String getSkuCode() {return skuCode;}
	public void setSkuCode(String skuCode) {this.skuCode = skuCode;}

	public String getSkuCategoryDesc() {
		return skuCategoryDesc;
	}

	public void setSkuCategoryDesc(String skuCategoryDesc) {
		this.skuCategoryDesc = skuCategoryDesc;
	}

	public Integer getMinAmount() {return minAmount;}
	public void setMinAmount(Integer minAmount) {
		if (minAmount == null) {
			minAmount = 1;
		}
		this.minAmount = minAmount;
	}

	public Integer getCombined() {return combined;}
	public void setCombined(Integer combined) {this.combined = combined;}

	public String getAttrs() {
		return attrs;
	}

	public void setAttrs(String attrs) {
		this.attrs = attrs;
	}

	public BigDecimal getSalesPrice() {return salesPrice;}
	public void setSalesPrice(BigDecimal salesPrice) {this.salesPrice = salesPrice;}

	public BigDecimal getSingleSkuSalesPrice() {
		return singleSkuSalesPrice;
	}

	public void setSingleSkuSalesPrice(BigDecimal singleSkuSalesPrice) {
		this.singleSkuSalesPrice = singleSkuSalesPrice;
	}

	public String getSkuCategoryName() {
		return skuCategoryName;
	}

	public void setSkuCategoryName(String skuCategoryName) {
		this.skuCategoryName = skuCategoryName;
	}

	public Integer getActive() {return active;}
	public void setActive(Integer active) {this.active = active;}

	public String getBu() {
		return bu;
	}

	public void setBu(String bu) {
		this.bu = bu;
	}

	public String getAttrValue1() {
		return attrValue1;
	}

	public void setAttrValue1(String attrValue1) {
		this.attrValue1 = attrValue1;
	}

	public String getAttrValue2() {
		return attrValue2;
	}

	public void setAttrValue2(String attrValue2) {
		this.attrValue2 = attrValue2;
	}

	public String getAttrValue3() {
		return attrValue3;
	}

	public void setAttrValue3(String attrValue3) {
		this.attrValue3 = attrValue3;
	}

	public String getSpvImg() {
		return spvImg;
	}

	public void setSpvImg(String spvImg) {
		this.spvImg = spvImg;
	}

	public Integer getShowCombinedPrice() {
		return showCombinedPrice;
	}

	public void setShowCombinedPrice(Integer showCombinedPrice) {
		this.showCombinedPrice = showCombinedPrice;
	}
}
